==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/screenshot/translations/screenshot_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuración general</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Seleccionar el formato de imagen, en cual las capturas de pantalla se guardarán y enviarán.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Forzar la extensión .jpg para el formato JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Forzar usar la extensión corta .jpg para archivos en formato JPEG. Algunos otros mensajeros instantáneos lo necesitan.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Calidad de las capturas de pantalla</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 para detección automática, 0 para mejor compresión de archivos, 100 para mejor calidad de imagen.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Directorio</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Ruta de directorio de las capturas de pantalla</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Prefijo de nombre de archivo de las capturas de pantalla</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Habilitar control de tamaño de directorio</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Tamaño máximo de directorio</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Límite del tamaño de las imágenes de captura de pantalla</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Formato de archivo de la captura de pantalla</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Pegar la imagen en la ventana de conversación automáticamente</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Cuando está habilitado, el complemento pegará automáticamente  listo para enviar la cláusula [IMAGEN] en la ventana de conversación.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Cuando está habilitado, el complemento comprobará el tamaño del directorio de las tomas y le avisará si llega al tamaño especificado abajo.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Defina, cuantos kilobytes pueden ocupar las tomas en el directorio antes que el complemento le avisará.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>El tamaño de la imagen es más grande que el tamaño máximo de imagen para esta conversación.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>¡No se puede crear el directorio %1 para almacenar las capturas de pantalla!</translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation>No se puede escribir el archivo %1.
¡Acceso denegado u otro problema!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>¡La captura de pantalla %1 tiene 0 de tamaño!
Debería ser más grande.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>ScreenShot</source>
        <translation>Captura de Pantalla</translation>
    </message>
    <message>
        <source>Simple Shot</source>
        <translation>Toma Simple</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>Con la ventana de conversación oculta</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Toma de la Ventana</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Tamaño límite de la captura de pantalla</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>El tamaño límite de las imágenes excede: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Arrastre este icono a la ventana deseada</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Toma de la Ventana</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/screenshot/translations/screenshot_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuración general</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Seleccionar el formato de imagen, en cual las capturas de pantalla se guardarán y enviarán.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Forzar la extensión .jpg para el formato JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Forzar usar la extensión corta .jpg para archivos en formato JPEG. Algunos otros mensajeros instantáneos lo necesitan.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Calidad de las capturas de pantalla</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 para detección automática, 0 para mejor compresión de archivos, 100 para mejor calidad de imagen.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Directorio</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Ruta de directorio de las capturas de pantalla</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Prefijo de nombre de archivo de las capturas de pantalla</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Habilitar control de tamaño de directorio</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Tamaño máximo de directorio</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Límite del tamaño de las imágenes de captura de pantalla</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Formato de archivo de la captura de pantalla</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Pegar la imagen en la ventana de conversación automáticamente</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Cuando está habilitado, el complemento pegará automáticamente  listo para enviar la cláusula [IMAGEN] en la ventana de conversación.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Cuando está habilitado, el complemento comprobará el tamaño del directorio de las tomas y le avisará si llega al tamaño especificado abajo.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Defina, cuantos kilobytes pueden ocupar las tomas en el directorio antes que el complemento le avisará.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>El tamaño de la imagen es más grande que el tamaño máximo de imagen para esta conversación.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>¡No se puede crear el directorio %1 para almacenar las capturas de pantalla!</translation>
    </message>
    <message>
        <source>Can't write file %1.
Access denied or other problem!</source>
        <translation>No se puede escribir el archivo %1.
¡Acceso denegado u otro problema!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>¡La captura de pantalla %1 tiene 0 de tamaño!
Debería ser más grande.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>Simple Shot</source>
        <translation>Toma Simple</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>Con la ventana de conversación oculta</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Toma de la Ventana</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotificationService</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Tamaño límite de la captura de pantalla</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>El tamaño límite de las imágenes excede: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Arrastre este icono a la ventana deseada</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Toma de la Ventana</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
</TS>
